package com.zfire.jiasm.syncdata.download.basedata;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.zfire.jiasm.syncdata.constant.DictTypeEnum;
import com.zfire.jiasm.syncdata.constant.InterFaceTypeEnum;
import com.zfire.jiasm.syncdata.data.Token;
import com.zfire.jiasm.syncdata.plus.entity.Brand;
import com.zfire.jiasm.syncdata.plus.entity.ItfTblAssignGzdmDowload;
import com.zfire.jiasm.syncdata.plus.entity.RepairBug;
import com.zfire.jiasm.syncdata.plus.entity.SysDict;
import com.zfire.jiasm.syncdata.plus.service.BrandService;
import com.zfire.jiasm.syncdata.plus.service.ItfTblAssignGzdmDowloadService;
import com.zfire.jiasm.syncdata.plus.service.RepairBugService;
import com.zfire.jiasm.syncdata.plus.service.SysDictService;
import com.zfire.jiasm.syncdata.utils.HttpUtil;
import com.zfire.jiasm.syncdata.utils.JSONResult;
import com.zfire.jiasm.syncdata.utils.TokenCenter;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.StringUtils;

import javax.annotation.Resource;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.stream.Collectors;

/**
 * 格力品牌固障代码基础资料下载
 */
@Slf4j
@Component
public class GLPPGuZhandDaiMa {
    @Value("${baseurl}")
    private String baseurl = "";

    @Resource
    TokenCenter tokenCenter;
    @Resource
    BrandService brandService;
    @Resource
    ItfTblAssignGzdmDowloadService itfTblAssignGzdmDowloadService;
    @Resource
    SysDictService sysDictService;
    @Resource
    RepairBugService repairBugService;





    /**
     * 格力品牌固障代码资料信息同步
     * @return
     */
    @Scheduled(fixedDelay = 1 * 60 * 1000)
    @Transactional(rollbackFor = Exception.class)
    public void processGZDMTask() throws Exception {
        if (1==1){
            return;
        }

        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        Map<String, String> paramMap = new HashMap<String, String>();

        log.info("开始下载格力品牌固障代码信息: {}",sdf.format(new Date()));

        // 提取品牌信息
        Brand brandRec = brandService.lambdaQuery().eq(Brand::getBrand,"格力").one();
        if (brandRec == null){
            log.info("格力品牌信息不存在【brand】");
            return;
        }

        Token token = tokenCenter.getCurrentToken();
        String url = baseurl + InterFaceTypeEnum.GELI_GZDM.getCode() + "/querylist";
        String paramJson= JSON.toJSONString(paramMap);

        JSONResult jsonResult = HttpUtil.httpRequestWithToken(url, "POST", paramJson, token);
        if (jsonResult.getStatus() == null || !jsonResult.getStatus().toString().equals("200")) {
            log.info("下载格力品牌固障代码信息失败！: {}",jsonResult.getMessage());
            return;
        }

        JSONArray jsonArray = (JSONArray) jsonResult.getData();
        if (jsonArray != null) {
            List<ItfTblAssignGzdmDowload> addRec = new ArrayList<>();
            List<ItfTblAssignGzdmDowload> updateRec = new ArrayList<>();

            log.info("下载了{}条数据",jsonArray.size());

            // 数据同步落到同步信息表
            extractedGZDMAddOrUpdate(jsonArray, addRec, updateRec);

            // 数据同步到本地故障现象表
            extractedGZDMLocalAddOrUpdate(brandRec, addRec, updateRec);


            log.info("格力品牌固障代码处理完成: {}",sdf.format(new Date()));
        }else {
            log.info("["+url+"]无数据");
        }
    }

    private void extractedGZDMLocalAddOrUpdate(Brand brandRec, List<ItfTblAssignGzdmDowload> addRec, List<ItfTblAssignGzdmDowload> updateRec) {
        Boolean flag = Boolean.FALSE;
        List<RepairBug> addRepairBug = new ArrayList<>();
        List<RepairBug> updateRepairBug = new ArrayList<>();
        // 提取小类字典数据
        List<SysDict> oldSysDictRec =  sysDictService.lambdaQuery().eq(SysDict::getDictType, DictTypeEnum.DICT_TYPE_SMALL_TYPE.getCode()).list();
        List<String> oldSysDictReclist = oldSysDictRec.stream().map(SysDict::getDictValue).collect(Collectors.toList());
        Map<String, List<SysDict>> oldSysDictRecMap = oldSysDictRec.stream().collect(Collectors.groupingBy(SysDict::getDictValue));

        // 提取大类字典数据
        List<SysDict> oldDSysDictRec =  sysDictService.lambdaQuery().eq(SysDict::getDictType, DictTypeEnum.DICT_TYPE_MAIN_TYPE.getCode()).list();
        Map<String, List<SysDict>> oldDSysDictRecMap = oldDSysDictRec.stream().collect(Collectors.groupingBy(SysDict::getDictCode));


        // 提取原有数据
        List<RepairBug> oldRepairBugRec =  repairBugService.lambdaQuery()
                .eq(RepairBug::getBrandId, brandRec.getBrandId()).list();
        Map<String, List<RepairBug>> oldRepairBugRecMap = oldRepairBugRec.stream().collect(Collectors.groupingBy(RepairBug::getGzid));

        // 获取新增的
        if (addRec.size()>0){
            for (ItfTblAssignGzdmDowload item : addRec){
                // 类别不存在不新增
                if (oldSysDictReclist.contains(item.getLeib())){
                    RepairBug v = new RepairBug();
                    v.setBugId(UUID.randomUUID().toString());
                    v.setGzid(String.valueOf(item.getGzid()));
                    v.setBrandId(brandRec.getBrandId());
                    v.setBrandName(brandRec.getBrand());
                    // 类别不为空时
                    if (oldSysDictRecMap.get(item.getLeib()).get(0)!=null){
                        // 小类编号
                        v.setSmallId(oldSysDictRecMap.get(item.getLeib()).get(0).getDictCode());
                        // 小类名称
                        v.setSmallName(oldSysDictRecMap.get(item.getLeib()).get(0).getDictValue());
                        // 小类有对应的父类时 提取父类信息
                        if (!StringUtils.isEmpty(oldSysDictRecMap.get(item.getLeib()).get(0).getParentDictCode())){
                            v.setMainId(oldSysDictRecMap.get(item.getLeib()).get(0).getParentDictCode());
                            v.setMainName(oldDSysDictRecMap.get(v.getMainId()).get(0).getDictValue());
                            v.setMainFlag(oldDSysDictRecMap.get(v.getMainId()).get(0).getFlag());
                        }
                    }
                    v.setBugObj(item.getGzmc());
                    if (item.getGzno() !=null ){
                        v.setBugObjCode(item.getGzno());
                    }
                    v.setStatus(DictTypeEnum.DICT_TYPE_OFF.getCode());
                    if (item.getFlag().equals(DictTypeEnum.DICT_TYPE_FLAG_ON.getCode())){
                        v.setStatus(DictTypeEnum.DICT_TYPE_ON.getCode());
                    }
                    v.setCreateBy("system");
                    v.setCreateTime(new Date());
                    if (item.getCjren() !=null){
                        v.setCreateBy(item.getCjren());
                    }
                    if (item.getCjdt() != null){
                        v.setCreateTime(item.getCjdt());
                    }
                    addRepairBug.add(v);
                }
            }
        }
        // 获取修改的
        if (updateRec.size()>0){
            for (ItfTblAssignGzdmDowload item : updateRec){
                flag = Boolean.FALSE;
                // 类别不存在不修改
                if (oldSysDictReclist.contains(item.getLeib())){
                    SysDict v = oldSysDictRecMap.get(item.getLeib()).get(0);
                    RepairBug old = oldRepairBugRecMap.get(item.getGzid()).get(0);

                    if (oldSysDictRecMap.get(item.getLeib()).get(0)!=null){
                        if (!old.getSmallId().equals(oldSysDictRecMap.get(item.getLeib()).get(0).getDictCode())){
                            flag = Boolean.TRUE;
                            old.setSmallId(oldSysDictRecMap.get(item.getLeib()).get(0).getDictCode());
                            old.setSmallName(oldSysDictRecMap.get(item.getLeib()).get(0).getDictValue());
                            old.setMainId(oldSysDictRecMap.get(item.getLeib()).get(0).getParentDictCode());
                            old.setMainName(oldDSysDictRecMap.get(old.getMainId()).get(0).getDictValue());
                            old.setMainFlag(oldDSysDictRecMap.get(old.getMainId()).get(0).getFlag());
                        }
                    }
                    if (!old.getBugObj().equals(item.getGzmc())){
                        old.setBugObj(item.getGzmc());
                        flag = Boolean.TRUE;
                    }
                    if (item.getGzno() !=null || old.getBugObjCode() !=null ){
                        if (item.getGzno() !=null && old.getBugObjCode() !=null){
                            if (!item.getGzno().equals(old.getBugObjCode())){
                                old.setBugObjCode(item.getGzno());
                                flag = Boolean.TRUE;
                            }
                        } else {
                            flag = Boolean.TRUE;
                            if (item.getGzno() !=null){
                                old.setBugObjCode(item.getGzno());
                            } else {
                                old.setBugObjCode(null);
                            }
                        }
                    }

                    // 修改的为有效
                    if (item.getFlag().equals(DictTypeEnum.DICT_TYPE_FLAG_ON.getCode())){
                        if (old.getStatus().equals(DictTypeEnum.DICT_TYPE_OFF.getCode())){
                            old.setStatus(DictTypeEnum.DICT_TYPE_ON.getCode());
                            flag = Boolean.TRUE;
                        }
                    } else {
                        if (old.getStatus().equals(DictTypeEnum.DICT_TYPE_ON.getCode())){
                            old.setStatus(DictTypeEnum.DICT_TYPE_OFF.getCode());
                            flag = Boolean.TRUE;
                        }
                    }
                    if (flag){
                        old.setUpdateBy("system");
                        old.setUpdateTime(new Date());
                        if (item.getLastModifiedBy() !=null ){
                            old.setUpdateBy(item.getLastModifiedBy());
                        }
                        if (item.getLastModifiedDate() !=null ){
                            old.setUpdateTime(item.getLastModifiedDate());
                        }
                        updateRepairBug.add(old);
                    }
                }
            }
        }

        // 新增的插入到表
        if (addRepairBug.size()>0){
            repairBugService.saveBatch(addRepairBug);
            log.info("格力品牌固障代码本地信息表新增插入了{}条数据",addRepairBug.size());
        }
        // 更新
        if (updateRepairBug.size()>0){
            repairBugService.updateBatchById(updateRepairBug);
            log.info("格力品牌固障代码本地信息表更新修改了{}条数据", updateRepairBug.size());
        }
    }

    private void extractedGZDMAddOrUpdate(JSONArray jsonArray, List<ItfTblAssignGzdmDowload> addRec, List<ItfTblAssignGzdmDowload> updateRec) {
        Boolean flag = Boolean.FALSE;
        String synTaskNo = UUID.randomUUID().toString();
        // 提取现有的数据信息
        List<ItfTblAssignGzdmDowload> oldRec =  itfTblAssignGzdmDowloadService.lambdaQuery().list();
        List<Long> oldRecId = oldRec.stream().map(ItfTblAssignGzdmDowload::getGzid).collect(Collectors.toList());
        Map<Long, List<ItfTblAssignGzdmDowload>> oldRecMap = oldRec.stream().collect(Collectors.groupingBy(ItfTblAssignGzdmDowload::getGzid));
        for (int i = 0; i < jsonArray.size(); i++) {
            flag = Boolean.FALSE;
            JSONObject aData = jsonArray.getJSONObject(i);
            ItfTblAssignGzdmDowload item = JSON.toJavaObject(aData,ItfTblAssignGzdmDowload.class);
            // 新增或修改数据

            // 修改
            if (oldRecId.contains(item.getGzid())){
                ItfTblAssignGzdmDowload old = oldRecMap.get(item.getGzid()).get(0);
                if (old.getGzno() !=null || item.getGzno() !=null){
                    if (old.getGzno() !=null && item.getGzno() !=null){
                        if (!old.getGzno().equals(item.getGzno())){
                            old.setGzno(item.getGzno());
                            flag = Boolean.TRUE;
                        }
                    } else {
                        flag = Boolean.TRUE;
                        if (item.getGzno() !=null) {
                            old.setGzno(item.getGzno());
                        } else {
                            old.setGzno("");
                        }
                    }
                }

                if (!old.getGzmc().equals(item.getGzmc())){
                    old.setGzmc(item.getGzmc());
                    flag = Boolean.TRUE;
                }
                if (!old.getPxdj().equals(item.getPxdj())){
                    old.setPxdj(item.getPxdj());
                    flag = Boolean.TRUE;
                }
                if (!old.getFlag().equals(item.getFlag())){
                    old.setFlag(item.getFlag());
                    flag = Boolean.TRUE;
                }
                if (!old.getLeib().equals(item.getLeib())){
                    old.setLeib(item.getLeib());
                    flag = Boolean.TRUE;
                }
                if (old.getCjwdno() !=null || item.getCjwdno() !=null){
                    if (old.getCjwdno() !=null && item.getCjwdno() !=null){
                        if (!old.getCjwdno().equals(item.getCjwdno())){
                            old.setCjwdno(item.getCjwdno());
                            flag = Boolean.TRUE;
                        }
                    } else {
                        flag = Boolean.TRUE;
                        if (item.getCjwdno() !=null) {
                            old.setCjwdno(item.getCjwdno());
                        } else {
                            old.setCjwdno("");
                        }
                    }
                }
                if (flag){
                    old.setLastModifiedBy("system");
                    old.setLastModifiedDate(new Date());
                    // 操作人
                    if (item.getLastModifiedBy() != null){
                        old.setLastModifiedBy(item.getLastModifiedBy());
                    }
                    // 修改时间
                    if (item.getLastModifiedDate() != null){
                        old.setLastModifiedDate(item.getLastModifiedDate());
                    }
                    updateRec.add(old);
                }
            } else {
                // 新增
                item.setSynTaskNo(synTaskNo);
                if (item.getCreatedBy() ==null){
                    item.setCreatedBy("system");
                }
                if (item.getCreatedDate() == null){
                    item.setCreatedDate(new Date());
                }
                addRec.add(item);
            }
        }
        // 新增的插入到表
        if (addRec.size()>0){
            itfTblAssignGzdmDowloadService.saveBatch(addRec);
            log.info("格力品牌固障代码信息同步新增插入了{}条数据", addRec.size());
        }

        // 更新
        if (updateRec.size()>0){
            itfTblAssignGzdmDowloadService.updateBatchById(updateRec);
            log.info("格力品牌固障代码信息同步更新修改了{}条数据", updateRec.size());
        }
    }
}
