package com.zfire.jiasm.syncdata.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.zfire.jiasm.syncdata.constant.DictTypeEnum;
import com.zfire.jiasm.syncdata.plus.entity.*;
import com.zfire.jiasm.syncdata.plus.service.*;
import com.zfire.jiasm.syncdata.response.WebsitPP;
import com.zfire.jiasm.syncdata.response.WebsitSH;
import com.zfire.jiasm.syncdata.service.PublicService;
import org.jetbrains.annotations.NotNull;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

@Service
public class PublicServiceImpl implements PublicService {
    @Resource
    OrderWorkerService orderWorkerService;
    @Resource
    SysDictRefService sysDictRefService;
    @Resource
    WebsitOrderSignService websitOrderSignService;
    @Resource
    CustomerInformationWebsitService customerInformationWebsitService;
    @Resource
    BrandWebsitService brandWebsitService;
    @Resource
    WebsitService websitService;


    @Override
    public OrderWorker getOrderWorker(OrderBase orderBase){
        if (StringUtils.isNotEmpty(orderBase.getWorkerName())){
            OrderWorker orderWorker = new OrderWorker();
            orderWorker.setOrderBaseId(orderBase.getId());
            orderWorker.setWorkerId(orderBase.getWorkerId());
            orderWorker.setWorkerName(orderBase.getWorkerName());
            orderWorker.setWorkerMobile(orderBase.getWorkerMobile());
            orderWorker.setWorkerIdcard(orderBase.getWorkerIdcard());
            orderWorker.setIsMaster(Boolean.TRUE);
            orderWorker.setBrandPgid(orderBase.getPgid());
            orderWorker.setPgguid(orderBase.getPgguid());
            orderWorker.setCreateTime(orderBase.getCreateTime());
            orderWorker.setCreateBy(orderBase.getCreateBy());
            orderWorker.setOutWorkerSource(Boolean.FALSE);

            orderWorkerService.save(orderWorker);

            return orderWorker;
        }

        return null;
    }

    @Override
    public List<OrderWorker> getWorker(String workerId,String orderBaseId) {
        List<OrderWorker> ows = orderWorkerService.lambdaQuery()
                .eq(OrderWorker::getOrderBaseId,orderBaseId)
                .eq(OrderWorker::getOutWorkerSource,Boolean.FALSE).list();
        return ows;
    }

    @Override
    public void deleteWorker(String orderBaseId){
        QueryWrapper del = new QueryWrapper<OrderWorker>()
                .eq("order_base_id", orderBaseId);

        orderWorkerService.remove(del);
    }


    @Override
    public Map<String, List<SysDictRef>> getStringListMap(Brand brand){
        List<SysDictRef> sysDictRef;
        Map<String, List<SysDictRef>> sysDictRefDLMap = new HashMap<>();
        sysDictRef =  sysDictRefService.lambdaQuery()
                .select(SysDictRef::getDictCode,SysDictRef::getDictValue,SysDictRef::getRefDictCode)
                .eq(SysDictRef::getBrandId, brand.getBrandId())
                .eq(SysDictRef::getDictType, DictTypeEnum.DICT_TYPE_MAIN_TYPE.getCode())
                .list();
        sysDictRefDLMap = sysDictRef.stream().
                collect(Collectors.groupingBy(SysDictRef::getRefDictCode));
        return sysDictRefDLMap;
    }

    @Override
    public Map<String, List<SysDictRef>> getListMap(Brand brand){
        List<SysDictRef> sysDictxlRef;
        Map<String, List<SysDictRef>> sysDictRefXLMap = new HashMap<>();
        sysDictxlRef =  sysDictRefService.lambdaQuery()
                .select(SysDictRef::getDictCode,SysDictRef::getDictValue,SysDictRef::getRefDictCode)
                .eq(SysDictRef::getBrandId, brand.getBrandId())
                .eq(SysDictRef::getDictType, DictTypeEnum.DICT_TYPE_SMALL_TYPE.getCode())
                .list();
        sysDictRefXLMap = sysDictxlRef.stream().
                collect(Collectors.groupingBy(SysDictRef::getRefDictCode));
        return sysDictRefXLMap;
    }

    @Override
    public Map<String, List<SysDictRef>> getMap(Brand brand){
        List<SysDictRef> sysDictxilieRef;
        Map<String, List<SysDictRef>> sysDictRefXiLieMap = new HashMap<>();
        sysDictxilieRef =  sysDictRefService.lambdaQuery()
                .select(SysDictRef::getDictCode,SysDictRef::getDictValue,SysDictRef::getRefDictCode)
                .eq(SysDictRef::getBrandId, brand.getBrandId())
                .eq(SysDictRef::getDictType, DictTypeEnum.DICT_TYPE_SERIES.getCode())
                .list();
        sysDictRefXiLieMap = sysDictxilieRef.stream().
                collect(Collectors.groupingBy(SysDictRef::getRefDictCode));
        return sysDictRefXiLieMap;
    }

    @Override
    public String getSHWDPhone(String websitNo){
        Websit websit = websitService.lambdaQuery()
                .eq(Websit::getWebsitId,websitNo)
                .one();
        if (websit != null){
            if (StringUtils.isNotEmpty(websit.getHotline())){
                return websit.getHotline();
            } else if (StringUtils.isNotEmpty(websit.getOfficePhone()))
                return websit.getOfficePhone();
        }
        return "";
    }

    // 品牌网点对应商户网点
    @Override
    public WebsitSH WebsitToSH(String websitNo, String brandId){
        WebsitSH resultData = new WebsitSH();

        resultData.setWdId("");
        resultData.setWdmc("");
        resultData.setWdlxdh("");

        // 先从售后网点查
        WebsitOrderSign wos = websitOrderSignService.lambdaQuery()
                .eq(WebsitOrderSign::getBrandWebsitNumber, websitNo)
                .eq(WebsitOrderSign::getBrandId, brandId)
                .one();
        if (wos != null){
            resultData.setWdId(wos.getWebsitId());
        } else {
            CustomerInformationWebsit ciwx = customerInformationWebsitService.lambdaQuery()
                    .eq(CustomerInformationWebsit::getRefWebsitId, websitNo)
                    .eq(CustomerInformationWebsit::getBrandId, brandId)
                    .one();
            if (ciwx !=null){
                resultData.setWdId(ciwx.getWebsitId());
            }
        }

        // 提取网点名称
        if (StringUtils.isNotEmpty(resultData.getWdId())){
            Websit websit = websitService.lambdaQuery()
                    .eq(Websit::getWebsitId,resultData.getWdId())
                    .one();
            if (websit != null){
                resultData.setWdmc(websit.getWebsitName());
                if (StringUtils.isNotEmpty(websit.getHotline())){
                    resultData.setWdlxdh(websit.getHotline());
                } else if (StringUtils.isNotEmpty(websit.getOfficePhone()))
                resultData.setWdlxdh(websit.getOfficePhone());
            }
        }

        return resultData;
    }

    // 商户网点对应品牌网点
    @Override
    public WebsitPP WebsitToPP(String websitId, String brandId){
        WebsitPP resultData = new WebsitPP();

        resultData.setXtwdno("");
        resultData.setWdno("");
        resultData.setWdmc("");

        // 先从售后网点查
        WebsitOrderSign wos = websitOrderSignService.lambdaQuery()
                .eq(WebsitOrderSign::getWebsitId, websitId)
                .eq(WebsitOrderSign::getBrandId, brandId)
                .one();
        if (wos != null){
            resultData.setWdno(wos.getBrandWebsitNumber());
            resultData.setWdmc(wos.getBrandWebsitName());
        } else {
            CustomerInformationWebsit ciwx = customerInformationWebsitService.lambdaQuery()
                    .eq(CustomerInformationWebsit::getWebsitId, websitId)
                    .eq(CustomerInformationWebsit::getBrandId, brandId)
                    .one();
            if (ciwx !=null){
                resultData.setWdno(ciwx.getRefWebsitId());
                resultData.setWdmc(ciwx.getRefWebsitName());
            }
        }

        // 提取系统网点编号
        if (StringUtils.isNotEmpty(resultData.getWdno())){
            BrandWebsit bw = brandWebsitService.lambdaQuery()
                    .eq(BrandWebsit::getBrandWebsitNumber, resultData.getWdno())
                    .eq(BrandWebsit::getBrandId, brandId)
                    .one();
            if (bw != null){
                resultData.setXtwdno(bw.getSysWebsitNumber());
            }

        }

        return resultData;
    }


    @Override
    public OutJiasmToGreeUploadTaskList getUploadTaskList(String orderNo, String id, Date updateTime,
                                                          String itemTableName, String itemOrderType, int taskType) {
        OutJiasmToGreeUploadTaskList add = new OutJiasmToGreeUploadTaskList();
        add.setUploadTaskType(taskType);
        add.setOrderNo(orderNo);
        add.setId(id);
        add.setTableName(itemTableName);
        add.setOrderType(itemOrderType);
        add.setSynReqTime(new Date());
        add.setUpdatetime(updateTime);
        return add;
    }

    @Override
    public OutJiasmToGreeUploadTaskList getUploadTaskList(String orderNo, String id,
                                                          String itemTableName, String itemOrderType, int taskType) {
        OutJiasmToGreeUploadTaskList add = new OutJiasmToGreeUploadTaskList();
        add.setUploadTaskType(taskType);
        add.setOrderNo(orderNo);
        add.setId(id);
        add.setTableName(itemTableName);
        add.setOrderType(itemOrderType);
        add.setSynReqTime(new Date());
        return add;
    }

}
