package com.zfire.jiasm.syncdata.upload.order;

import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.zfire.jiasm.syncdata.base.BaseService;
import com.zfire.jiasm.syncdata.constant.DictTypeEnum;
import com.zfire.jiasm.syncdata.constant.GDOrderStatusEnum;
import com.zfire.jiasm.syncdata.constant.OrderTypeEnum;
import com.zfire.jiasm.syncdata.dao.mapper.*;
import com.zfire.jiasm.syncdata.parameter.*;
import com.zfire.jiasm.syncdata.plus.entity.*;
import com.zfire.jiasm.syncdata.plus.service.*;
import com.zfire.jiasm.syncdata.response.WebsitPP;
import lombok.extern.slf4j.Slf4j;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.stream.Collectors;

/**
 * 生成需要上传的数据
 * 1：数据准备类型定义表提取数据 select * from out_jiasm_to_gree_upload_task_type;
 * 2：根据类型定义表的任务类型 从数据上传任务表提取对应的任务类型数据 select * from out_jiasm_to_gree_upload_task_list;
 * 生成相应的upload数据插入表中
 * 上传任务表中的 tablename+ordertype处理不同类型的工单
 *    orderer_base+INSTALL为安装工单
 * 	     工单基础表中提取工单数据 select * from order_base;
 * 				条件判断是否需要生成数据
 * 				生成上传的工单主表数据 select * from itf_tbl_az_assign_lc_ls_upload;
 * 				根据辅材订单支付表存在支付时生成安装费用数据
 * 				select * from order_pay_outlay_item;
 * 				select * from itf_tbl_az_assign_fee_upload;
 * 				生成安装采集数据 select * from order_install_detail;
 * 			    	生成不同的完工明细数据
 * 					select * from itf_tbl_az_wgmx_jykt_upload;
 * 					select * from itf_tbl_az_wgmx_sykt_upload;
 * 					select * from itf_tbl_az_wgmx_qita_upload;
 * 				生成采集附件数据 select * from order_detail_file;
 * 			    	生成不同的采集除件数据
 * 					select * from itf_tbl_az_wgmx_jykt_fj_upload;
 * 					select * from itf_tbl_az_wgmx_sykt_fj_upload;
 * 					select * from itf_tbl_az_wgmx_qita_fj_upload;
 * 				生成条码明细数据 select * from order_install_detail_code;
 * 			    	生成不同的条码数据
 * 					select * from itf_tbl_az_wgmx_jykt_tmmx_upload;
 * 					select * from itf_tbl_az_wgmx_sykt_tmmx_ls_upload;
 * 					select * from itf_tbl_az_wgmx_qita_tmmx_upload;
 * 				生成短信评价数据 select * from itf_messagehuifangentity;
 * 				修改上传任务表同步状态 select * from out_jiasm_to_gree_upload_task_list
 *    order_install_operating_log+INSTALL为安装工单操作明细
 * 	     修改 order_install_operating_log 表数据
 * 	     生成 itf_tbl_az_assign_fkmx_upload 表数据
 * 	     修改上传任务表同步状态 select * from out_jiasm_to_gree_upload_task_list
 *
 *
 *
 *
 * 修改上传任务表的状态
 */

@Slf4j
@Component
public class InstallProduceDataUploadList {

    @Resource
    InstallProduceDataUploadList installProduceDataUploadList;
    @Resource
    OutJiasmToGreeUploadTaskTypeService outJiasmToGreeUploadTaskTypeService;
    @Resource
    OutJiasmToGreeUploadTaskListService outJiasmToGreeUploadTaskListService;
    @Resource
    OrderBaseService orderBaseService;
    @Resource
    GDOrderBaseMapper gdOrderBaseMapper;
    @Resource
    BaseService baseService;
    @Resource
    BrandLbsRelateService brandLbsRelateService;
    @Resource
    AreaService areaService;
    @Resource
    StreetService streetService;
    @Resource
    OJTGUploadTaskListMapper ojtgUploadTaskListMapper;
    @Resource
    ItfTblAzAssignLcLsUploadService itfTblAzAssignLcLsUploadService;
    @Resource
    OrderInstallDetailService orderInstallDetailService;
    @Resource
    DetailOrderInstallMapper detailOrderInstallMapper;
    @Resource
    SysDictRefService sysDictRefService;
    @Resource
    WebsitOrderSignService websitOrderSignService;
    @Resource
    CustomerInformationWebsitService customerInformationWebsitService;
    @Resource
    BrandWebsitService brandWebsitService;
    @Resource
    ItfTblWangdianWxgDownloadService itfTblWangdianWxgDownloadService;
    @Resource
    FileOrderDetailMapper fileOrderDetailMapper;
    @Resource
    OrderDetailFileService orderDetailFileService;
    @Resource
    ItfTblAzWgmxJyktFjUploadService itfTblAzWgmxJyktFjUploadService;
    @Resource
    ItfTblAzWgmxSyktFjUploadService itfTblAzWgmxSyktFjUploadService;
    @Resource
    ItfTblAzWgmxQitaFjUploadService itfTblAzWgmxQitaFjUploadService;
    @Resource
    ItfTblAzWgmxJyktUploadService itfTblAzWgmxJyktUploadService;
    @Resource
    ItfTblAzWgmxSyktUploadService itfTblAzWgmxSyktUploadService;
    @Resource
    ItfTblAzWgmxQitaUploadService itfTblAzWgmxQitaUploadService;
    @Resource
    CodeOrderInstallDetailMapper codeOrderInstallDetailMapper;
    @Resource
    OrderInstallDetailCodeService orderInstallDetailCodeService;
    @Resource
    ItfTblAzWgmxJyktTmmxUploadService itfTblAzWgmxJyktTmmxUploadService;
    @Resource
    ItfTblAzWgmxSyktTmmxLsUploadService itfTblAzWgmxSyktTmmxLsUploadService;
    @Resource
    ItfTblAzWgmxQitaTmmxUploadService itfTblAzWgmxQitaTmmxUploadService;
    @Resource
    ItfMessagehuifangentityService itfMessagehuifangentityService;
    @Resource
    OrderPayOutlayItemService orderPayOutlayItemService;
    @Resource
    OrderInstallService orderInstallService;
    @Resource
    ItfTblAzAssignFeeUploadService itfTblAzAssignFeeUploadService;
    @Resource
    OperatingLogOrderInstallMapper operatingLogOrderInstallMapper;
    @Resource
    ItfTblAzAssignFkmxUploadService itfTblAzAssignFkmxUploadService;
    @Resource
    ReAppointmentOrderMapper reAppointmentOrderMapper;
    @Resource
    ItfTblAzAssignAppointmentUploadService itfTblAzAssignAppointmentUploadService;




    @Scheduled(fixedDelay = 1 * 20 * 1000)
    private void produceList(){
        if (1==1){
            return;
        }

        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");

        // 提取品牌信息
        Brand brand = baseService.getBrand();
        if (brand == null) {
            return;
        }

        // 提取大类信息
        List<SysDictRef> sysDictRefRecs =  sysDictRefService.lambdaQuery()
                .select(SysDictRef::getRefDictName,
                        SysDictRef::getDictCode)
                .eq(SysDictRef::getBrandId, brand.getBrandId())
                .eq(SysDictRef::getDictType, DictTypeEnum.DICT_TYPE_MAIN_TYPE.getCode())
                .list();
        Map<String, List<SysDictRef>> CategoryRefmap = sysDictRefRecs.stream().collect(Collectors.groupingBy(SysDictRef::getDictCode));

        log.info("开始生成需要上传的安装工单数据: {}",sdf.format(new Date()));

        // 上传任务清单表中提取所有数据
        List<OutJiasmToGreeUploadTaskType> ojtutts = outJiasmToGreeUploadTaskTypeService.lambdaQuery()
                .orderByAsc(OutJiasmToGreeUploadTaskType::getId).list();
        try{
            for (OutJiasmToGreeUploadTaskType item:ojtutts){
                // 任务类型
                int uploadTaskType = item.getUploadTaskType();

                // 数据上传任务表提取对应的任务类型数据
                List<OutJiasmToGreeUploadTaskList> ojtutls = outJiasmToGreeUploadTaskListService.lambdaQuery()
                        .eq(OutJiasmToGreeUploadTaskList::getSynStatus,0)
                        .eq(OutJiasmToGreeUploadTaskList::getUploadTaskType,uploadTaskType)
                        .orderByAsc(OutJiasmToGreeUploadTaskList::getSynReqId).list();
                for (OutJiasmToGreeUploadTaskList ojtutl:ojtutls){
                    // 安装工单数据生成
                    // 同步任务表中的主键,安装工单号,源表主键
                    // TL_PrePareSynDataby_fa_order_install_test

                    // 安装工单 基础表数据同步
                    if (ojtutl.getTableName().equals("order_base") &&
                            ojtutl.getOrderType().equals(OrderTypeEnum.ORDER_TYPE_INSTALL.getCode())){
                        if (installProduceDataUploadList.orderBaseInstall(brand, ojtutl, CategoryRefmap)) {
                            continue;
                        }
                    }

                    // 安装工单操作明细 TL_PrePareSynDataby_fa_order_install_operating_log
                    if (ojtutl.getTableName().equals("order_install_operating_log") &&
                            ojtutl.getOrderType().equals(OrderTypeEnum.ORDER_TYPE_INSTALL.getCode())){
                        installProduceDataUploadList.getFkmx(brand, ojtutl);
                    }

                    // 安装工单用户改约明细 与操作明细最好放在一起，因表设计分开两天，所以独立开来处理
                    if (ojtutl.getTableName().equals("order_re_appointment") &&
                            ojtutl.getOrderType().equals(OrderTypeEnum.ORDER_TYPE_INSTALL.getCode())){
                        getAppointment(ojtutl);
                    }



                }
            }

            log.info("生成需要上传的安装工单数据结束: {}",sdf.format(new Date()));

        } catch (Exception ex) {
            ex.printStackTrace();
            log.info("开始预处理生成需要上传的安装工单数据出错");
        }
    }

    @Transactional(rollbackFor = Exception.class)
    public  void getAppointment(OutJiasmToGreeUploadTaskList ojtutl) {
        OrderBase orderBase = orderBaseService.lambdaQuery()
                .eq(OrderBase::getId, ojtutl.getOrderNo()).one();
        if (orderBase !=null ){
            ReAppointment request = new ReAppointment();
            request.setOrderNo(ojtutl.getOrderNo());
            request.setId(ojtutl.getId());
            ItfTblAzAssignAppointmentUpload add = reAppointmentOrderMapper.getReAppointment(request);
            itfTblAzAssignAppointmentUploadService.save(add);
        }

        // 修改数据上传任务表中的状态 单号,id,同步状态,类型
        updateUploadTaskList(ojtutl.getOrderNo(), ojtutl.getSynReqId(),1, ojtutl.getUploadTaskType());
    }

    @Transactional(rollbackFor = Exception.class)
    public void getFkmx(Brand brand, OutJiasmToGreeUploadTaskList ojtutl) {
        OrderBase orderBase = orderBaseService.lambdaQuery()
                .eq(OrderBase::getId, ojtutl.getOrderNo()).one();
        if (orderBase !=null ){
            // 修改fikd
            OperatingLog request = new OperatingLog();
            request.setFkid(UUID.randomUUID().toString());
            request.setId(ojtutl.getId());
            operatingLogOrderInstallMapper.upLogfkid(request);

            // 修改pgguid
            OperatingLog up = new OperatingLog();
            up.setOrderNo(ojtutl.getOrderNo());
            up.setPgguid(UUID.randomUUID().toString());
            operatingLogOrderInstallMapper.upLogpgguid(up);

            OperatingLog que = new OperatingLog();
            que.setOrderNo(ojtutl.getOrderNo());
            que.setId(ojtutl.getId());
            ItfTblAzAssignFkmxUpload add = operatingLogOrderInstallMapper.getOperatingLog(que);
            add.setUploadTaskSynReqId(ojtutl.getSynReqId());

            // 反馈人取了网点编号需单独处理 fkren   网点编号+01
            // 反馈网点编号 做同样处理
            WebsitPP resultData = getPPWebsitInfo(add.getFkren(), brand.getBrandId());
            add.setFkren(resultData.getWdno()+"01");
            add.setXtwdbh(resultData.getXtwdno());
            add.setWdno(resultData.getWdno());
            add.setWdmc(resultData.getWdmc());
            itfTblAzAssignFkmxUploadService.save(add);
        }

        // 修改数据上传任务表中的状态 单号,id,同步状态,类型
        updateUploadTaskList(ojtutl.getOrderNo(), ojtutl.getSynReqId(),1, ojtutl.getUploadTaskType());
    }


    private WebsitPP getPPWebsitInfo(String websitId, String brandId){
        WebsitPP resultData = new WebsitPP();

        resultData.setXtwdno("");
        resultData.setWdno("");
        resultData.setWdmc("");

        // 先从售后网点查
        WebsitOrderSign wos = websitOrderSignService.lambdaQuery()
                .eq(WebsitOrderSign::getWebsitId, websitId)
                .eq(WebsitOrderSign::getBrandId, brandId)
                .one();
        if (wos != null){
            resultData.setWdno(wos.getBrandWebsitNumber());
            resultData.setWdmc(wos.getBrandWebsitName());
        } else {
            CustomerInformationWebsit ciwx = customerInformationWebsitService.lambdaQuery()
                    .eq(CustomerInformationWebsit::getWebsitId, websitId)
                    .eq(CustomerInformationWebsit::getBrandId, brandId)
                    .one();
            if (ciwx !=null){
                resultData.setWdno(ciwx.getRefWebsitId());
                resultData.setWdmc(ciwx.getRefWebsitName());
            }
        }

        // 提取系统网点编号
        if (StringUtils.isNotEmpty(resultData.getWdno())){
            BrandWebsit bw = brandWebsitService.lambdaQuery()
                    .eq(BrandWebsit::getBrandWebsitNumber, resultData.getWdno())
                    .eq(BrandWebsit::getBrandId, brandId)
                    .one();
            if (bw != null){
                resultData.setXtwdno(bw.getSysWebsitNumber());
            }

        }

        return resultData;
    }

    @Transactional(rollbackFor = Exception.class)
    public boolean orderBaseInstall(Brand brand, OutJiasmToGreeUploadTaskList ojtutl, Map<String, List<SysDictRef>> CategoryRefmap) {
        OrderBase orderBase = orderBaseService.lambdaQuery()
                .eq(OrderBase::getId, ojtutl.getId()).one();

        if (orderBase !=null ){
            // 若工单被删除不再同步 不写生成数据

            // 条件判断
            if (checkPare(ojtutl, orderBase)) {
                return true;
            }

            // 安装工单产品信息,操作日志,完工明细,完工明细附件 以主表的pgguid统一修改
            // 生成待同步的工单主表数据
            ItfTblAzAssignLcLsUpload lcls = getItfTblAzAssignLcLsUpload(brand, ojtutl);
            // 插入工单主表数据
            itfTblAzAssignLcLsUploadService.save(lcls);

            // 生成安装辅材费用数据
            getFeeUpload(orderBase);

            // 生成采集数据 采集明细，采集附件，采集条码(及家用，商用、其他)
            generateCJData(brand, CategoryRefmap, orderBase, lcls);

            // 生成评价短信 只写一次
            getPJmessage(orderBase, lcls);
        }

        // 修改数据上传任务表中的状态   这里固定值 22
        updateUploadTaskList(ojtutl.getOrderNo(),ojtutl.getSynReqId(),1,22);

        return false;
    }

    private void getFeeUpload(OrderBase orderBase) {
        // 根据辅材订单支付表存在支付时生成安装费用数据
        List<OrderPayOutlayItem> pitems = orderPayOutlayItemService.lambdaQuery()
                .eq(OrderPayOutlayItem::getOrderBaseId, orderBase.getId()).list();
        if (pitems!=null && pitems.size()>0){
            BigDecimal totalAmount=BigDecimal.ZERO;
            for (OrderPayOutlayItem ps :pitems){
                totalAmount = totalAmount.add(ps.getTotalAmount());
            }

            ItfTblAzAssignFeeUpload feeUpload = new ItfTblAzAssignFeeUpload();
            // 从工单扩展表提取辅材信息
            OrderInstall orderInstall =orderInstallService.lambdaQuery()
                    .eq(OrderInstall::getOrderBaseId, orderBase.getId()).one();
            if (orderInstall !=null){
                feeUpload.setWorkerOrderNo(orderBase.getId());
                feeUpload.setId(orderBase.getPgguid());
                feeUpload.setCreatedBy("guangfo");
                feeUpload.setCreatedDate(orderInstall.getCreateTime());
                feeUpload.setLastModifiedBy("guangfo");
                feeUpload.setLastModifiedDate(orderInstall.getUpdateTime());
                feeUpload.setOtherfee(String.valueOf(totalAmount));
                feeUpload.setTotalfee(String.valueOf(totalAmount));
                feeUpload.setAjia(orderInstall.getBracket());
                feeUpload.setJcguan(orderInstall.getPipe());
                feeUpload.setKqkg(orderInstall.getSwithFlag());
                feeUpload.setGkzy(orderInstall.getHighAltitude());
                feeUpload.setYccxqk(orderInstall.getHole());
                feeUpload.setFlbz(orderBase.getId());
            } else {
                feeUpload.setWorkerOrderNo(orderBase.getId());
                feeUpload.setId(orderBase.getPgguid());
                feeUpload.setCreatedBy("guangfo");
                feeUpload.setCreatedDate(orderBase.getCreateTime());
                feeUpload.setLastModifiedBy("guangfo");
                feeUpload.setLastModifiedDate(orderBase.getUpdateTime());
                feeUpload.setOtherfee(String.valueOf(totalAmount));
                feeUpload.setTotalfee(String.valueOf(totalAmount));
                feeUpload.setFlbz(orderBase.getId());
            }

            itfTblAzAssignFeeUploadService.save(feeUpload);
        }
    }

    private void getPJmessage(OrderBase orderBase, ItfTblAzAssignLcLsUpload lcls) {
        // 生成评价短信 不能写在产品中要写在表头，只写一次 派工状态为4(1304，1309与工单状态相同) 完工或已关闭的单
        if (orderBase.getOrderStatus().equals(GDOrderStatusEnum.INSTALL_STATUS_G7.getCode()) ||
                orderBase.getOrderStatus().equals(GDOrderStatusEnum.INSTALL_STATUS_G10.getCode())) {
            if (!orderBase.getUploadFlag()){
                // 查看是否已发送
                ItfMessagehuifangentity message = itfMessagehuifangentityService.lambdaQuery()
                        .eq(ItfMessagehuifangentity::getOrderBaseId, orderBase.getId()).one();

                if (message == null){
                    String fsma = getfsma();
                    // 生成短信数据
                    ItfMessagehuifangentity addms = new ItfMessagehuifangentity();
                    String id = UUID.randomUUID().toString();
                    if (id.length()>32){
                        addms.setSynTaskNo(id.substring(0,32));
                    } else {
                        addms.setSynTaskNo(id);
                    }

                    addms.setOrderBaseId(orderBase.getId());
                    addms.setSendtype(2);
                    addms.setAzorwx(1);
                    addms.setCrdt(new Date());
                    addms.setFjid(orderBase.getPgguid());
                    addms.setFjwd(lcls.getJspgwdno());
                    addms.setFsma(fsma);
                    addms.setFsnr("尊敬的用户：请对本次服务评价：满意回复1；一般回复2；不满意回复3。并注明原因！关注官微“格力售后服务”，为您提供更优质服务！");
                    addms.setSjid(orderBase.getUserMobile().replace(" ",""));

                    Calendar cal =Calendar.getInstance();
                    cal.setTime(new Date());
                    cal.add(Calendar.HOUR,2);
                    addms.setPlansendtime(cal.getTime());

                    itfMessagehuifangentityService.save(addms);
                }
            } else if ((orderBase.getOrderStatus().equals(GDOrderStatusEnum.INSTALL_STATUS_G7.getCode()) ||
                    orderBase.getOrderStatus().equals(GDOrderStatusEnum.INSTALL_STATUS_G10.getCode())) &&
                    !orderBase.getSaleType().equals("工程机"))  {
                // 查看是否已发送
                ItfMessagehuifangentity message = itfMessagehuifangentityService.lambdaQuery()
                        .eq(ItfMessagehuifangentity::getOrderBaseId, orderBase.getId()).one();

                if (message == null){
                    String fsma = getfsma();
                    // 生成短信数据
                    ItfMessagehuifangentity addms = new ItfMessagehuifangentity();
                    addms.setSynTaskNo(UUID.randomUUID().toString());
                    addms.setOrderBaseId(orderBase.getId());
                    addms.setAzorwx(1);
                    addms.setCrdt(new Date());
                    addms.setFjid(orderBase.getPgguid());
                    addms.setFjwd(lcls.getJspgwdno());
                    addms.setFsma(fsma);
                    addms.setFsnr("尊敬的用户：请对本次服务评价：满意回复1；一般回复2；不满意回复3。并注明原因！关注官微“格力售后服务”，为您提供更优质服务！");
                    addms.setSjid(orderBase.getUserMobile().replace(" ",""));

                    itfMessagehuifangentityService.save(addms);
                }
            }
        }
    }

    @NotNull
    private String getfsma() {
        Random random = new Random(System.currentTimeMillis());
        String fsma = String.valueOf(random.nextInt(10000));

        if (fsma.length()<4){
            if (fsma.length()==3){
                fsma = fsma + "9";
            } else if (fsma.length()==2){
                fsma = fsma + "99";
            } else {
                fsma = fsma + "999";
            }
        }
        return fsma;
    }

    private void generateCJData(Brand brand, Map<String, List<SysDictRef>> CategoryRefmap, OrderBase orderBase, ItfTblAzAssignLcLsUpload lcls) {
        // 工单状态order_status 6, 7, 9, 10 且为非预派工订单
        if ((orderBase.getOrderStatus().equals(GDOrderStatusEnum.INSTALL_STATUS_G6.getCode()) ||
                orderBase.getOrderStatus().equals(GDOrderStatusEnum.INSTALL_STATUS_G7.getCode()) ||
                orderBase.getOrderStatus().equals(GDOrderStatusEnum.INSTALL_STATUS_G9.getCode()) ||
                orderBase.getOrderStatus().equals(GDOrderStatusEnum.INSTALL_STATUS_G10.getCode())) &&
                orderBase.getIsReservation().equals(0)){
            // 提取采集的数据
            List<OrderInstallDetail> orderInstallDetails = orderInstallDetailService.lambdaQuery()
                    .eq(OrderInstallDetail::getOrderBaseId, orderBase.getId())
                    .orderByAsc(OrderInstallDetail::getId)
                    .list();
            Map<String, Integer> val = new HashMap<String,Integer>();

            if (orderInstallDetails !=null && orderInstallDetails.size()>0){
                for (OrderInstallDetail detail :orderInstallDetails){
                    // 状态:3=临时保存;2=作废,1=已采集,0=未采集
                    // 临时保存与未采集的记录不处理
                    if (detail.getStatus().equals(0) || detail.getStatus().equals(3)){
                        continue;
                    }

                    // 获取完工采集明细数据 (家用空调、商用空调、其他)
                    String mainName = getCJMXData(brand, CategoryRefmap, orderBase, lcls, detail);

                    // 获取采集附件数据 (家用、商用、其他)
                    getcjfjdata(orderBase, detail, mainName);

                    // 生成条码明细数据
                    getDetailCode(orderBase, detail, mainName);

                }

            }
        }
    }

    private void getDetailCode(OrderBase orderBase, OrderInstallDetail detail, String mainName) {
        // 获取条码采集明细id
        InstalDetailCode instalDetailCode = new InstalDetailCode();
        instalDetailCode.setOrderNo(detail.getOrderBaseId());
        instalDetailCode.setId(detail.getId());
        List<OrderInstallDetailCode> codes = codeOrderInstallDetailMapper.getId(instalDetailCode);
        // 处理条码明细
        for (OrderInstallDetailCode code :codes){
            if (StringUtils.isEmpty(code.getPath())){
                continue;
            }
            if (StringUtils.isEmpty(code.getGreeImageId())){
                continue;
            }

            if (StringUtils.isEmpty(code.getTmguid())){
                OrderInstallDetailCode upCode = new OrderInstallDetailCode();
                upCode.setId(code.getId());
                upCode.setTmguid(UUID.randomUUID().toString());
                orderInstallDetailCodeService.updateById(upCode);
            }
            // 采集明细表中取pgwcmxid
            OrderInstallDetail orderInstallDetail = orderInstallDetailService.lambdaQuery()
                    .eq(OrderInstallDetail::getOrderBaseId,code.getOrderBaseId())
                    .eq(OrderInstallDetail::getId,code.getOrderDetailId()).one();
            if (orderInstallDetail == null || StringUtils.isEmpty(orderInstallDetail.getPgwcmxid())){
                continue;
            } else {
                OrderInstallDetailCode upCode = new OrderInstallDetailCode();
                upCode.setId(code.getId());
                upCode.setPgwcmxid(orderInstallDetail.getPgwcmxid());
                orderInstallDetailCodeService.updateById(upCode);
            }

            // 生成采集条码表数据
            generateDetailCode(orderBase, detail, mainName);
        }
    }

    private void generateDetailCode(OrderBase orderBase, OrderInstallDetail detail, String mainName) {
        // 采集条码表中的pgguid 统一改成工单基础表的pgguid
        InstalDetailCode upcode = new InstalDetailCode();
        upcode.setOrderNo(detail.getOrderBaseId());
        upcode.setPgguId(orderBase.getPgguid());
        codeOrderInstallDetailMapper.updateCodePgguid(upcode);

        InstalDetailCode codep = new InstalDetailCode();
        codep.setOrderNo(detail.getOrderBaseId());
        codep.setId(detail.getId());

        if (mainName.equals("家用空调") ||
                mainName.equals("家用空气能热水器") ||
                mainName.equals("驻车空调")) {
            // 家用空调 完工明细 数据生成(完工采集条码数据)
            ItfTblAzWgmxJyktTmmxUpload jy = codeOrderInstallDetailMapper.getJyCode(codep);
            if (jy != null){
                itfTblAzWgmxJyktTmmxUploadService.save(jy);
            }
        } else if (mainName.equals("商用空调")){
            // 家用空调 完工明细 数据生成(完工采集条码数据)
              ItfTblAzWgmxSyktTmmxLsUpload sy = codeOrderInstallDetailMapper.getSyCode(codep);
            if (sy != null){
                itfTblAzWgmxSyktTmmxLsUploadService.save(sy);
            }
        } else {
            ItfTblAzWgmxQitaTmmxUpload other = codeOrderInstallDetailMapper.getOtherCode(codep);
            if (other != null){
                itfTblAzWgmxQitaTmmxUploadService.save(other);
            }
        }
    }

    @Nullable
    private String getCJMXData(Brand brand, Map<String, List<SysDictRef>> CategoryRefmap, OrderBase orderBase,
                               ItfTblAzAssignLcLsUpload lcls, OrderInstallDetail detail) {
        // 修改采集明细的序 pgwcmxid 生成格力总部-采集明细序号
        upCerrentRec(detail);
        // 采集表中的pgguid 统一改成工单基础表的pgguid
        upInstallDetailPgguid(orderBase);

        // 采集表与采集条码表ID超范围 - 采集表及采集明细表中的outid统一修改
        upOutId(detail);

        // 根据产品类别名称 生成不同的完工明细数据
        String mainName = CategoryRefmap.get(orderBase.getMainId()).get(0).getRefDictName();
        // 采集标志 1100:保存,1110:作废,1120:转结算
        Integer cjstat = 1100;

        if (orderBase.getOrderStatus().equals(GDOrderStatusEnum.INSTALL_STATUS_G7.getCode()) ||
                orderBase.getOrderStatus().equals(GDOrderStatusEnum.INSTALL_STATUS_G10.getCode())){
            cjstat = 1120;
        }
        if (detail.getStatus().equals(2)){
            cjstat = 1110;
        }

        InstallDetail request = new InstallDetail();
        request.setOrderNo(detail.getOrderBaseId());
        request.setId(detail.getId());
        request.setBrandId(brand.getBrandId());
        // 为空时为 家用空调
        if (StringUtils.isEmpty(mainName) ||
                mainName.equals("家用空调") || mainName.equals("家用空气能热水器") || mainName.equals("驻车空调")){
            // 家用空调 完工明细 数据生成(完工采集数据)
            ItfTblAzWgmxJyktUpload mxup = detailOrderInstallMapper.getOrderInstallUpload(request);
            if (mxup != null){
                // 部分参数单独处理
                setParm(brand, orderBase, lcls, cjstat, mxup, detail);
                itfTblAzWgmxJyktUploadService.save(mxup);
            }
        } else if (mainName.equals("商用空调")){
            // 商用空调 完工明细数据生成(完工采集数据)
            ItfTblAzWgmxSyktUpload mxup = detailOrderInstallMapper.getSyOrderInstallUpload(request);
            if (mxup != null){
                // 部分参数单独处理
                setSyParm(brand, orderBase, lcls, cjstat, mxup, detail);
                itfTblAzWgmxSyktUploadService.save(mxup);
            }
        } else {
            // 其他 完工明细数据生成
            // 获取家用空调完工明细(完工采集数据)
            ItfTblAzWgmxQitaUpload mxup = detailOrderInstallMapper.getOtherOrderInstallUpload(request);
            if (mxup != null){
                // 部分参数单独处理
                setOtherParm(brand, orderBase, lcls, cjstat, mxup, detail);
                itfTblAzWgmxQitaUploadService.save(mxup);
            }
        }
        return mainName;
    }

    private void upOutId(OrderInstallDetail detail) {
        List<OrderInstallDetail> upList = new ArrayList<>();
        List<OrderInstallDetail> detaillist = orderInstallDetailService.lambdaQuery()
                .eq(OrderInstallDetail::getOrderBaseId, detail.getOrderBaseId())
                .eq(OrderInstallDetail::getOutId,0).list();
        // 找出最大的序 默认值为0
        int outId=0;
        if (detaillist!=null && detaillist.size()>0){
            for (OrderInstallDetail item:detaillist){
                if (outId<item.getOutId()){
                    outId = item.getOutId();
                }
            }
            for (OrderInstallDetail ite:detaillist){
                if (ite.getOutId() == 0){
                    outId++;
                    OrderInstallDetail n = new OrderInstallDetail();
                    n.setId(ite.getId());
                    n.setOutId(outId);
                    upList.add(n);
                }
            }
            // 修改序
            orderInstallDetailService.updateBatchById(upList);
        }

        // 采集条码码 outid统一修改
        // 采集表与采集条码表ID超范围 - 采集表及采集明细表中的outid统一修改
        List<OrderInstallDetailCode> codelist = orderInstallDetailCodeService.lambdaQuery()
                .eq(OrderInstallDetailCode::getOrderBaseId, detail.getOrderBaseId())
                .eq(OrderInstallDetailCode::getOutId,0).list();
        if (codelist!=null && codelist.size()>0){
            InstalDetailCode codep = new InstalDetailCode();
            codep.setOrderNo(detail.getOrderBaseId());
            codeOrderInstallDetailMapper.updateCodeOutId(codep);
        }
    }

    // 处理附件采集数据上传
    public void getcjfjdata(OrderBase orderBase, OrderInstallDetail detail, String mainName) {
        // 附件上传总部标识判断
        if (orderBase.getOrderStatus().equals(GDOrderStatusEnum.INSTALL_STATUS_G7.getCode()) ||
                orderBase.getOrderStatus().equals(GDOrderStatusEnum.INSTALL_STATUS_G10.getCode())){
            // 安装工单采集附件表提取数据
            InstallCJDetailFile installCJDetailFile = new InstallCJDetailFile();
            installCJDetailFile.setOrderNo(detail.getOrderBaseId());
            installCJDetailFile.setId(detail.getId());
            List<OrderDetailFile> detailFiles = fileOrderDetailMapper.getId(installCJDetailFile);
            for (OrderDetailFile file:detailFiles){
                // 工单号， file的id即附件表的id,uuid统一值
                // path未准备上传被忽略
                if (StringUtils.isEmpty(file.getFilePath())){
                    continue;
                }
                // 品牌方fileindex未获取上传被忽略
                if (StringUtils.isEmpty(file.getBrandFileIndex())){
                    continue;
                }
                // 提取获取采集明细表数据中获取pgwcmxid(生成格力总部-采集明细序号)
                OrderInstallDetail detailone = orderInstallDetailService.lambdaQuery()
                        .eq(OrderInstallDetail::getOrderBaseId,file.getOrderBaseId())
                        .eq(OrderInstallDetail::getId,file.getOrderDetailId()).one();

                // 获取完工明细数据(采集附件表) 家用、商用、其他
                getwgmxData(mainName, file, detailone);
            }
        }
    }

    public void getwgmxData(String mainName, OrderDetailFile file, OrderInstallDetail detailone) {
        // 修改附件的pgwcmxid
        if (detailone != null){
            OrderDetailFile upf = new OrderDetailFile();
            upf.setId(file.getId());
            upf.setPgwcmxid(detailone.getPgwcmxid());
            orderDetailFileService.updateById(upf);
        }
        // 采集附件表中的pgguid 统一改成工单基础表的pgguid 可以不用，从主表取即可 无pgguid字段
        /*InstallCJDetailFile upfile = new InstallCJDetailFile();
        upfile.setOrderNo(file.getOrderBaseId());
        upfile.setPgguId(orderBase.getPgguid());
        fileOrderDetailMapper.updateFilePgguid(upfile);*/


        // 修改附件的fjguid
        if (detailone != null){
            OrderDetailFile upf = new OrderDetailFile();
            upf.setId(file.getId());
            upf.setFjguid(UUID.randomUUID().toString());
            orderDetailFileService.updateById(upf);
        }

        InstallCJDetailFile request = new InstallCJDetailFile();
        request.setOrderNo(file.getOrderBaseId());
        request.setId(file.getId());

        // 生成家用空调 数据采集附件上传记录
        if (mainName.equals("家用空调") ||
                mainName.equals("家用空气能热水器") ||
                mainName.equals("驻车空调")){
            // 家用空调 完工明细 数据生成
            ItfTblAzWgmxJyktFjUpload jyktfj = fileOrderDetailMapper.getFileUpload(request);
            if (jyktfj !=null){
                itfTblAzWgmxJyktFjUploadService.save(jyktfj);
            }
        } else if (mainName.equals("商用空调")){
            // 商用空调 完工明细 数据生成
            ItfTblAzWgmxSyktFjUpload syktfj = fileOrderDetailMapper.getSyFileUpload(request);
            if (syktfj !=null){
                itfTblAzWgmxSyktFjUploadService.save(syktfj);
            }
        } else {
            // 其他 完工明细 数据生成
            ItfTblAzWgmxQitaFjUpload otherfj = fileOrderDetailMapper.getOtherFileUpload(request);
            if (otherfj != null){
                itfTblAzWgmxQitaFjUploadService.save(otherfj);
            }
        }
    }

    private void setParm(Brand brand, OrderBase orderBase, ItfTblAzAssignLcLsUpload lcls, Integer cjstat,
                         ItfTblAzWgmxJyktUpload mxup, OrderInstallDetail detail) {
        setJysWdno(brand, orderBase, mxup);
        mxup.setCjren(orderBase.getCreateBy());
        mxup.setCjrmc(orderBase.getCreateName());

        mxup.setStat(cjstat);
        if (cjstat.equals("1120")){
            if (orderBase.getOverTime()!=null){
                mxup.setWcsj(orderBase.getOverTime());
            } else {
                mxup.setWcsj(mxup.getLastModifiedDate());
            }
        }
        mxup.setAzwdno(lcls.getAzwdno());
        mxup.setAzwdmc(lcls.getAzwdmc());
        mxup.setAzwdxtbh(lcls.getAzwdxtbh());
        if (StringUtils.isEmpty(mxup.getSjcjgps())){
            mxup.setSjcjgps(orderBase.getAddress());
        }
        mxup.setGmsj(orderBase.getBuyTime());
        mxup.setCjwdno(mxup.getAzwdno());
        mxup.setZjczwd(mxup.getAzwdno());
        mxup.setSjcjjd(orderBase.getLat());
        mxup.setSjcjwd(orderBase.getLng());
        mxup.setSjcjjwdu(orderBase.getLat()+","+ orderBase.getLng());

        // 网点维修工ID单独处理
        // 先找出网点编号对应的品牌商网点编号
        // 先从售后网点查
        String brandWebsitNumber = "";
        WebsitOrderSign wos = websitOrderSignService.lambdaQuery()
                .eq(WebsitOrderSign::getWebsitId, detail.getWebsitId())
                .eq(WebsitOrderSign::getBrandId, brand.getBrandId())
                .one();
        if (wos != null){
            brandWebsitNumber = wos.getBrandWebsitNumber();
        } else {
            CustomerInformationWebsit ciwx = customerInformationWebsitService.lambdaQuery()
                    .eq(CustomerInformationWebsit::getWebsitId, detail.getWebsitId())
                    .eq(CustomerInformationWebsit::getBrandId, brand.getBrandId())
                    .one();
            if (ciwx !=null){
                brandWebsitNumber = ciwx.getRefWebsitId();
            }
        }


        ItfTblWangdianWxgDownload wxg = itfTblWangdianWxgDownloadService.lambdaQuery()
                .eq(ItfTblWangdianWxgDownload::getSfzen,mxup.getAzrenid())
                .eq(ItfTblWangdianWxgDownload::getWdno,brandWebsitNumber).one();

        if (wxg !=null){
            mxup.setAzrenid(wxg.getWxgid());
        }

    }

    private void setOtherParm(Brand brand, OrderBase orderBase, ItfTblAzAssignLcLsUpload lcls, Integer cjstat,
                              ItfTblAzWgmxQitaUpload mxup, OrderInstallDetail detail) {
        setOtherWdno(brand, orderBase, mxup);
        mxup.setCjren(orderBase.getCreateBy());
        mxup.setCjrmc(orderBase.getCreateName());

        mxup.setStat(cjstat);
        if (cjstat.equals("1120")){
            if (orderBase.getOverTime()!=null){
                mxup.setWcsj(orderBase.getOverTime());
            } else {
                mxup.setWcsj(mxup.getLastModifiedDate());
            }
        }
        mxup.setAzwdno(lcls.getAzwdno());
        mxup.setAzwdmc(lcls.getAzwdmc());
        mxup.setAzwdxtbh(lcls.getAzwdxtbh());
        if (StringUtils.isEmpty(mxup.getSjcjgps())){
            mxup.setSjcjgps(orderBase.getAddress());
        }
        mxup.setGmsj(orderBase.getBuyTime());
        mxup.setCjwdno(mxup.getAzwdno());
        mxup.setZjczwd(mxup.getAzwdno());
        mxup.setSjcjjd(orderBase.getLat());
        mxup.setSjcjwd(orderBase.getLng());
        mxup.setSjcjjwdu(orderBase.getLat()+","+ orderBase.getLng());

        // 网点维修工ID单独处理
        // 先找出网点编号对应的品牌商网点编号
        // 先从售后网点查
        String brandWebsitNumber = "";
        WebsitOrderSign wos = websitOrderSignService.lambdaQuery()
                .eq(WebsitOrderSign::getWebsitId, detail.getWebsitId())
                .eq(WebsitOrderSign::getBrandId, brand.getBrandId())
                .one();
        if (wos != null){
            brandWebsitNumber = wos.getBrandWebsitNumber();
        } else {
            CustomerInformationWebsit ciwx = customerInformationWebsitService.lambdaQuery()
                    .eq(CustomerInformationWebsit::getWebsitId, detail.getWebsitId())
                    .eq(CustomerInformationWebsit::getBrandId, brand.getBrandId())
                    .one();
            if (ciwx !=null){
                brandWebsitNumber = ciwx.getRefWebsitId();
            }
        }


        ItfTblWangdianWxgDownload wxg = itfTblWangdianWxgDownloadService.lambdaQuery()
                .eq(ItfTblWangdianWxgDownload::getSfzen,mxup.getAzrenid())
                .eq(ItfTblWangdianWxgDownload::getWdno,brandWebsitNumber).one();

        if (wxg !=null){
            mxup.setAzrenid(wxg.getWxgid());
        }

    }

    private void setSyParm(Brand brand, OrderBase orderBase, ItfTblAzAssignLcLsUpload lcls, Integer cjstat,
                           ItfTblAzWgmxSyktUpload mxup, OrderInstallDetail detail) {
        setSyWdno(brand, orderBase, mxup);
        mxup.setCjren(orderBase.getCreateBy());
        mxup.setCjrmc(orderBase.getCreateName());

        mxup.setStat(cjstat);
        if (cjstat.equals("1120")){
            if (orderBase.getOverTime()!=null){
                mxup.setWcsj(orderBase.getOverTime());
            } else {
                mxup.setWcsj(mxup.getLastModifiedDate());
            }
        }
        mxup.setAzwdno(lcls.getAzwdno());
        mxup.setAzwdmc(lcls.getAzwdmc());
        mxup.setAzwdxtbh(lcls.getAzwdxtbh());
        if (StringUtils.isEmpty(mxup.getSjcjgps())){
            mxup.setSjcjgps(orderBase.getAddress());
        }
        mxup.setGmsj(orderBase.getBuyTime());
        mxup.setCjwdno(mxup.getAzwdno());
        mxup.setZjczwd(mxup.getAzwdno());
        mxup.setSjcjjd(orderBase.getLat());
        mxup.setSjcjwd(orderBase.getLng());
        mxup.setSjcjjwdu(orderBase.getLat()+","+ orderBase.getLng());

        // 网点维修工ID单独处理
        // 先找出网点编号对应的品牌商网点编号
        // 先从售后网点查
        String brandWebsitNumber = "";
        WebsitOrderSign wos = websitOrderSignService.lambdaQuery()
                .eq(WebsitOrderSign::getWebsitId, detail.getWebsitId())
                .eq(WebsitOrderSign::getBrandId, brand.getBrandId())
                .one();
        if (wos != null){
            brandWebsitNumber = wos.getBrandWebsitNumber();
        } else {
            CustomerInformationWebsit ciwx = customerInformationWebsitService.lambdaQuery()
                    .eq(CustomerInformationWebsit::getWebsitId, detail.getWebsitId())
                    .eq(CustomerInformationWebsit::getBrandId, brand.getBrandId())
                    .one();
            if (ciwx !=null){
                brandWebsitNumber = ciwx.getRefWebsitId();
            }
        }


        ItfTblWangdianWxgDownload wxg = itfTblWangdianWxgDownloadService.lambdaQuery()
                .eq(ItfTblWangdianWxgDownload::getSfzen,mxup.getAzrenid())
                .eq(ItfTblWangdianWxgDownload::getWdno,brandWebsitNumber).one();

        if (wxg !=null){
            mxup.setAzrenid(wxg.getWxgid());
        }

    }

    private void setJysWdno(Brand brand, OrderBase orderBase, ItfTblAzWgmxJyktUpload mxup) {
        // 先从售后网点查
        WebsitOrderSign wos = websitOrderSignService.lambdaQuery()
                .eq(WebsitOrderSign::getWebsitId, orderBase.getLastOperatorWebsit())
                .eq(WebsitOrderSign::getBrandId, brand.getBrandId())
                .one();
        if (wos != null){
            mxup.setZjczwdxtbh(wos.getBrandWebsitNumber());
        } else {
            CustomerInformationWebsit ciwx = customerInformationWebsitService.lambdaQuery()
                    .eq(CustomerInformationWebsit::getWebsitId, orderBase.getLastOperatorWebsit())
                    .eq(CustomerInformationWebsit::getBrandId, brand.getBrandId())
                    .one();
            if (ciwx !=null){
                mxup.setZjczwdxtbh(ciwx.getRefWebsitId());
            }
        }

        BrandWebsit brandWebsit = brandWebsitService.lambdaQuery()
                .eq(BrandWebsit::getBrandWebsitNumber, mxup.getZjczwdxtbh())
                .one();
        mxup.setZjczwdxtbh(brandWebsit.getSysWebsitNumber());


        WebsitOrderSign wost = websitOrderSignService.lambdaQuery()
                .eq(WebsitOrderSign::getWebsitId, mxup.getJsdwxtbh())
                .eq(WebsitOrderSign::getBrandId, brand.getBrandId())
                .one();
        if (wost != null){
            mxup.setJsdwxtbh(wos.getBrandWebsitId());
        }

    }

    private void setSyWdno(Brand brand, OrderBase orderBase, ItfTblAzWgmxSyktUpload mxup) {
        // 先从售后网点查
        WebsitOrderSign wos = websitOrderSignService.lambdaQuery()
                .eq(WebsitOrderSign::getWebsitId, orderBase.getLastOperatorWebsit())
                .eq(WebsitOrderSign::getBrandId, brand.getBrandId())
                .one();
        if (wos != null){
            mxup.setZjczwdxtbh(wos.getBrandWebsitNumber());
        } else {
            CustomerInformationWebsit ciwx = customerInformationWebsitService.lambdaQuery()
                    .eq(CustomerInformationWebsit::getWebsitId, orderBase.getLastOperatorWebsit())
                    .eq(CustomerInformationWebsit::getBrandId, brand.getBrandId())
                    .one();
            if (ciwx !=null){
                mxup.setZjczwdxtbh(ciwx.getRefWebsitId());
            }
        }

        BrandWebsit brandWebsit = brandWebsitService.lambdaQuery()
                .eq(BrandWebsit::getBrandWebsitNumber, mxup.getZjczwdxtbh())
                .one();
        mxup.setZjczwdxtbh(brandWebsit.getSysWebsitNumber());


        WebsitOrderSign wost = websitOrderSignService.lambdaQuery()
                .eq(WebsitOrderSign::getWebsitId, mxup.getJsdwxtbh())
                .eq(WebsitOrderSign::getBrandId, brand.getBrandId())
                .one();
        if (wost != null){
            mxup.setJsdwxtbh(wos.getBrandWebsitId());
        }

    }

    private void setOtherWdno(Brand brand, OrderBase orderBase, ItfTblAzWgmxQitaUpload mxup) {
        // 先从售后网点查
        WebsitOrderSign wos = websitOrderSignService.lambdaQuery()
                .eq(WebsitOrderSign::getWebsitId, orderBase.getLastOperatorWebsit())
                .eq(WebsitOrderSign::getBrandId, brand.getBrandId())
                .one();
        if (wos != null){
            mxup.setZjczwdxtbh(wos.getBrandWebsitNumber());
        } else {
            CustomerInformationWebsit ciwx = customerInformationWebsitService.lambdaQuery()
                    .eq(CustomerInformationWebsit::getWebsitId, orderBase.getLastOperatorWebsit())
                    .eq(CustomerInformationWebsit::getBrandId, brand.getBrandId())
                    .one();
            if (ciwx !=null){
                mxup.setZjczwdxtbh(ciwx.getRefWebsitId());
            }
        }

        BrandWebsit brandWebsit = brandWebsitService.lambdaQuery()
                .eq(BrandWebsit::getBrandWebsitNumber, mxup.getZjczwdxtbh())
                .one();
        mxup.setZjczwdxtbh(brandWebsit.getSysWebsitNumber());


        WebsitOrderSign wost = websitOrderSignService.lambdaQuery()
                .eq(WebsitOrderSign::getWebsitId, mxup.getJsdwxtbh())
                .eq(WebsitOrderSign::getBrandId, brand.getBrandId())
                .one();
        if (wost != null){
            mxup.setJsdwxtbh(wos.getBrandWebsitId());
        }

    }

    public void upInstallDetailPgguid(OrderBase orderBase) {
        InstallDetail installDetail = new InstallDetail();
        installDetail.setOrderNo(orderBase.getId());
        installDetail.setPgguId(orderBase.getPgguid());
        detailOrderInstallMapper.installUpdatePgguid(installDetail);
    }

    public void upCerrentRec(OrderInstallDetail detail) {
        OrderInstallDetail updetail = new OrderInstallDetail();
        updetail.setId(detail.getId());
        updetail.setPgwcmxid(UUID.randomUUID().toString());
        orderInstallDetailService.updateById(updetail);
    }

    @NotNull
    private ItfTblAzAssignLcLsUpload getItfTblAzAssignLcLsUpload(Brand brand, OutJiasmToGreeUploadTaskList ojtutl) {
        OrderPar orderPar = new OrderPar();
        orderPar.setBrandId(brand.getBrandId());
        orderPar.setOrderNo(ojtutl.getId());
        ItfTblAzAssignLcLsUpload lcls = gdOrderBaseMapper.getAZOrderBase(orderPar);
        lcls.setUploadTaskSynReqId(ojtutl.getSynReqId());
        // 省市等信息单独处理
        setssxz(lcls);
        return lcls;
    }

    public void addAndUpdate(OutJiasmToGreeUploadTaskList ojtutl, ItfTblAzAssignLcLsUpload lcls) {

        // 插入工单主表数据
        itfTblAzAssignLcLsUploadService.save(lcls);

        // 修改数据上传任务表中的状态
        // updateUploadTaskList(ojtutl);
    }

    private void updateUploadTaskList(String orderNo, Long synReqId,
                                      Integer synStatus,Integer uploadTaskType) {
        OutJiasmToGreeUploadTaskList upoutgultl = new OutJiasmToGreeUploadTaskList();
        upoutgultl.setSynReqId(synReqId);
        upoutgultl.setSynStatus(synStatus);
        upoutgultl.setSynTime(new Date());
        outJiasmToGreeUploadTaskListService.updateById(upoutgultl);

        // 批量修改
        InstallUpdatePar request = new InstallUpdatePar();
        request.setOrderNo(orderNo);
        request.setUploadTaskType(uploadTaskType);
        request.setSynReqId(synReqId);
        ojtgUploadTaskListMapper.installUpdateuploadTaskList(request);
    }

    private boolean checkPare(OutJiasmToGreeUploadTaskList ojtutl, OrderBase orderBase) {
        // 接收派工网点为空上传忽略
        if (StringUtils.isEmpty(orderBase.getReceWebsitId()) || orderBase.getReceWebsitId().equals("0")){
            stopUpload(ojtutl, "接收派工网点为空上传忽略");
            return true;
        }
        if (StringUtils.isEmpty(orderBase.getPgguid()) || orderBase.getPgguid().equals("0")){
            stopUpload(ojtutl, "pgguid异常上传忽略");
            return true;
        }
        if (StringUtils.isEmpty(orderBase.getPgid()) || orderBase.getPgid().equals("0")){
            stopUpload(ojtutl, "pgid异常上传忽略");
            return true;
        }
        return false;
    }

    private void setssxz(ItfTblAzAssignLcLsUpload lcls){
        List<BrandLbsRelate> br;
        // 街道处理
        if (StringUtils.isNotEmpty(lcls.getXzhenid())){
            br = brandLbsRelateService.lambdaQuery()
                    .eq(BrandLbsRelate::getLbsStreetId, lcls.getXzhenid())
                    .isNotNull(BrandLbsRelate::getStreetId).list();
            if (br !=null && br.size()>0){
                lcls.setXzhenid(br.get(0).getStreetId());

                Street street = streetService.lambdaQuery()
                        .eq(Street::getProvince, lcls.getSfenid())
                        .eq(Street::getCity, lcls.getCshiid())
                        .eq(Street::getArea, lcls.getXianid())
                        .eq(Street::getStreet, lcls.getXzhenid()).one();
                if (street !=null){
                    lcls.setXzhen(street.getStreet());
                    lcls.setSfenid(Long.valueOf(street.getProvinceId()));
                    lcls.setCshiid(Long.valueOf(street.getCityId()));
                    lcls.setXianid(Long.valueOf(street.getAreaId()));

                    lcls.setSfen(street.getProvince());
                    lcls.setCshi(street.getCity());
                    lcls.setXian(street.getArea());
                    return;
                }
            }
        }

        //省
        br = brandLbsRelateService.lambdaQuery()
                .eq(BrandLbsRelate::getLbsProvinceId, lcls.getSfenid())
                .isNotNull(BrandLbsRelate::getProvinceId).list();
        if (br !=null && br.size()>0){
            lcls.setSfenid(Long.valueOf(br.get(0).getProvinceId()));
        }
        //市
        br = brandLbsRelateService.lambdaQuery()
                .eq(BrandLbsRelate::getLbsCityId, lcls.getCshiid())
                .isNotNull(BrandLbsRelate::getCityId).list();
        if (br !=null && br.size()>0){
            lcls.setCshiid(Long.valueOf(br.get(0).getCityId()));
        }
        //区
        br = brandLbsRelateService.lambdaQuery()
                .eq(BrandLbsRelate::getLbsDistrictId, lcls.getXianid())
                .isNotNull(BrandLbsRelate::getAreaId).list();
        if (br !=null && br.size()>0){
            lcls.setXianid(Long.valueOf(br.get(0).getAreaId()));
        }

        // 总部区必选
        Area area = areaService.lambdaQuery()
                .eq(Area::getAreaId, lcls.getXianid()).one();
        Street st = new Street();
        if (area !=null){
            lcls.setSfen(area.getProvince());
            lcls.setCshi(area.getCity());
            lcls.setXian(area.getArea());
        }
    }




    private void stopUpload(@NotNull OutJiasmToGreeUploadTaskList ojtutl, String msg) {
        OutJiasmToGreeUploadTaskList up = new OutJiasmToGreeUploadTaskList();
        up.setSynReqId(ojtutl.getSynReqId());
        up.setSynStatus(99);
        up.setSynTime(new Date());
        up.setSynErrMsg(msg);
        outJiasmToGreeUploadTaskListService.updateById(up);
    }

}
