package com.zfire.jiasm.syncdata.upload.order;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.zfire.jiasm.syncdata.base.BaseService;
import com.zfire.jiasm.syncdata.constant.DictTypeEnum;
import com.zfire.jiasm.syncdata.constant.OrderTypeEnum;
import com.zfire.jiasm.syncdata.dao.mapper.GDOrderBaseMapper;
import com.zfire.jiasm.syncdata.data.Token;
import com.zfire.jiasm.syncdata.parameter.OrderPar;
import com.zfire.jiasm.syncdata.plus.entity.*;
import com.zfire.jiasm.syncdata.plus.service.*;
import com.zfire.jiasm.syncdata.service.WorkerOrderUploadService;
import com.zfire.jiasm.syncdata.utils.HttpUtil;
import com.zfire.jiasm.syncdata.utils.JSONResult;
import com.zfire.jiasm.syncdata.utils.TokenCenter;
import lombok.extern.slf4j.Slf4j;
import org.jetbrains.annotations.NotNull;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.stream.Collectors;

/**
 * 生成需要上传的数据
 * 1：数据准备类型定义表提取数据 select * from out_jiasm_to_gree_upload_task_type;
 * 2：根据类型定义表的任务类型 从数据上传任务表提取对应的任务类型数据 select * from out_jiasm_to_gree_upload_task_list;
 * 生成相应的upload数据插入表中
 * 上传任务表中的 tablename+ordertype处理不同类型的工单
 *    orderer_base+INSTALL为安装工单

 * 修改上传任务表的状态
 */

@Slf4j
@Component
public class RepairProduceDataUploadList {
    @Value("${baseurl4pgid}")
    private String baseurl4pgid;
    @Value("${baseurl}")
    private String baseurl;


    @Autowired
    private TokenCenter tokenCenter;
    @Resource
    BaseService baseService;
    @Resource
    SysDictRefService sysDictRefService;
    @Resource
    OutJiasmToGreeUploadTaskTypeService outJiasmToGreeUploadTaskTypeService;
    @Resource
    OutJiasmToGreeUploadTaskListService outJiasmToGreeUploadTaskListService;
    @Resource
    OrderBaseService orderBaseService;
    @Resource
    OrderProductService orderProductService;
    @Resource
    OrderRepairOperatingLogService orderRepairOperatingLogService;
    @Resource
    FaGreeSmsService faGreeSmsService;
    @Resource
    GDOrderBaseMapper gdOrderBaseMapper;




    @Scheduled(fixedDelay = 1 * 20 * 1000)
    private void produceList() throws Exception {
        if (1==1){
            return;
        }

        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");

        // 提取品牌信息
        Brand brand = baseService.getBrand();
        if (brand == null) {
            return;
        }

        // 提取大类信息
        List<SysDictRef> sysDictRefRecs =  sysDictRefService.lambdaQuery()
                .select(SysDictRef::getRefDictName,
                        SysDictRef::getDictCode)
                .eq(SysDictRef::getBrandId, brand.getBrandId())
                .eq(SysDictRef::getDictType, DictTypeEnum.DICT_TYPE_MAIN_TYPE.getCode())
                .list();
        Map<String, List<SysDictRef>> CategoryRefmap = sysDictRefRecs.stream().collect(Collectors.groupingBy(SysDictRef::getDictCode));

        log.info("开始生成需要上传的修修工单数据: {}",sdf.format(new Date()));

        Token token = tokenCenter.getCurrentToken();

        // 1:类型定义表中提取数据
        List<OutJiasmToGreeUploadTaskType> taskTypes = outJiasmToGreeUploadTaskTypeService.lambdaQuery()
                .orderByAsc(OutJiasmToGreeUploadTaskType::getId).list();
        try{
            for (OutJiasmToGreeUploadTaskType taskType:taskTypes){
                // 任务类型
                int uploadTaskType = taskType.getUploadTaskType();
                // 需从格力系统获取的列名
                String greekeyName = taskType.getGreekeyName();
                // 获取列名对应的表名
                String srcTabNameForGreekey = taskType.getSrcTabNameForGreekey();
                String greekeyGetMode = taskType.getGreekeyGetMode();
                String greeInsColList = (String) taskType.getGreeInsColList();
                if (greeInsColList == null) {
                    greeInsColList = "";
                }
                // 2：数据上传任务清单表中提取对应任务类型的需要上传的数据
                List<OutJiasmToGreeUploadTaskList> result = outJiasmToGreeUploadTaskListService.lambdaQuery()
                        .eq(OutJiasmToGreeUploadTaskList::getSynStatus,0)
                        .eq(OutJiasmToGreeUploadTaskList::getUploadTaskType,uploadTaskType)
                        .orderByAsc(OutJiasmToGreeUploadTaskList::getSynReqId).list();
                // 相同任务类型的数据逐个处理
                for (OutJiasmToGreeUploadTaskList row: result){
                    Long taskId = row.getSynReqId();
                    try {
                        OutJiasmToGreeUploadTaskList sourceData = outJiasmToGreeUploadTaskListService.lambdaQuery()
                                .eq(OutJiasmToGreeUploadTaskList::getSynReqId,taskId).one();
                        if (!sourceData.getSynStatus().equals(0)){
                            continue;
                        }

                        String newDykh = "";
                        boolean isNeedGenRemoteId = false;
                        // 需从格力总部获取相对列值
                        if (greekeyName != null && greekeyName.trim().length() > 0 && srcTabNameForGreekey != null
                                && srcTabNameForGreekey.trim().length() > 0) {
                            newDykh = getpgid(token, uploadTaskType, srcTabNameForGreekey, greekeyGetMode, row, newDykh);
                            isNeedGenRemoteId = true;
                        }

                        // 过程名称，同步任务表中的id,同步任务表中的工单号，同步任务表中的需同步的表的主键，pgid-主键，true
                        // 66 - TL_PrePareSynDataby_fa_order_repair_test
                        // 安装工单 基础表数据同步
                        if (row.getTableName().equals("order_base") &&
                                row.getOrderType().equals(OrderTypeEnum.ORDER_TYPE_INSTALL.getCode())){
                            // 提取工单数据
                            OrderBase orderBase = orderBaseService.lambdaQuery()
                                    .eq(OrderBase::getId,sourceData.getOrderNo()).one();

                            // 删除工单更新被忽略

                            // 接收派工网点为空上传被忽略
                            if (StringUtils.isEmpty(orderBase.getReceWebsitId()) || orderBase.getReceWebsitId().equals("0")){
                                continue;
                            }
                            // 同步工单的pgid
                            upOrderBasePgid(sourceData, orderBase,newDykh);
                            // 同步工单的pguuid
                            upOrderBasePgguid(sourceData, orderBase);
                            // 同步维修工单产品信息 pgid从工单主表中取
                            // 同步维修工单操作日志pgid
                            uporderRepairOperatingLogpgid(sourceData, orderBase, newDykh);
                            // 同步预约改约-总部短信发送请求fjid
                            upFaGreeSmsFjid(sourceData, newDykh);
                            // 同步派服务人员-短信发送请求fjid todo
                            // 数据写入待同步-维修工单上传记录表
                            OrderPar orderPar = new OrderPar();
                            orderPar.setBrandId(brand.getBrandId());
                            orderPar.setOrderNo(sourceData.getOrderNo());
                            ItfTblAssignUpload itass = gdOrderBaseMapper.getItfTblAssignUpload(orderPar);



                            // 661 - TL_PrePareSynDataby_assign_cj

                        }

                    } catch (Exception ex) {

                    }
                    // 修改 itf_fa_to_gree_upload_task_list
                }
            }
            log.info("生成需要上传的维修工单数据结束: {}",sdf.format(new Date()));
        } catch (Exception ex) {
            ex.printStackTrace();
            log.info("开始预处理生成需要上传的维修工单数据出错");
        }
    }

    private String getpgid(Token token, int uploadTaskType, String srcTabNameForGreekey, String greekeyGetMode, OutJiasmToGreeUploadTaskList row, String newDykh) throws Exception {
        // 获取方式 Qry=从控制表获取 Ins=插入表获取自增列
        String greeKey;
        if (greekeyGetMode != null && greekeyGetMode.equalsIgnoreCase("Ins")) {
            // 暂无

        } else if (uploadTaskType == 66 || uploadTaskType == 661) {
            // pgid从主表中获取
            OrderBase ob = orderBaseService.lambdaQuery()
                    .eq(OrderBase::getId, row.getOrderNo()).one();
            greeKey = ob.getPgid();
            if (greeKey == null || greeKey.trim().equals("") || greeKey.trim().equals("0")) {
                Token token4Pgid = tokenCenter.getCurrentToken4Pgid();
                String url = baseurl4pgid + "api/repairEnter/getPgidSerial";
                JSONObject jsonObject = HttpUtil.httpRequestGetPgid(url, "POST", token4Pgid, null,
                        null);
                if (jsonObject.getString("statusCode").equals("200")) {
                    String data = jsonObject.getString("data");
                    newDykh = data;
                } else {
                    String message = jsonObject.getString("message");
                    if (message == null || message.trim().length() == 0) {
                        message = "取pgid失败";
                    }
                    throw new Exception(message);
                }
            } else {
                newDykh = greeKey;
            }
        } else if (uploadTaskType == 68) {
            // 从工单机型表中取
            OrderProduct op = orderProductService.lambdaQuery()
                    .eq(OrderProduct::getOrderBaseId, row.getOrderNo())
                    .eq(OrderProduct::getProductId, row.getId()).one();
            greeKey = op.getPgmxid();
            if (greeKey == null || greeKey.trim().equals("") || greeKey.trim().equals("0")) {

                Token token4Pgid = tokenCenter.getCurrentToken4Pgid();
                String url = baseurl4pgid + "api/repairEnter/getMxIdserial";
                JSONObject jsonObject = HttpUtil.httpRequestGetPgid(url, "POST", token4Pgid, null,
                        null);
                if (jsonObject.getString("statusCode").equals("200")) {
                    String data = jsonObject.getString("data");
                    newDykh = data;
                } else {
                    String message = jsonObject.getString("message");
                    if (message == null || message.trim().length() == 0) {
                        message = "取pgmxid失败";
                    }
                    throw new Exception(message);
                }

            } else {
                newDykh = greeKey;
            }
        } else {
            String url = baseurl + "konghao/getDykh";
            Map<String, String> paramMap = new HashMap<String, String>();
            paramMap.put("tabName", srcTabNameForGreekey);
            JSONResult jsonResult = HttpUtil.httpRequestWithToken(url, "POST",
                    JSON.toJSONString(paramMap), token);
            if (!jsonResult.isOK()) {
                throw new Exception("取dykh失败[" + jsonResult.getMsg() + "]");
            }
            JSONObject data = (JSONObject) jsonResult.getData();
            newDykh = data.getString("newDykh");
        }
        return newDykh;
    }

    private void upFaGreeSmsFjid(OutJiasmToGreeUploadTaskList sourceData, String newDykh) {
        FaGreeSms up = new FaGreeSms();
        up.setFjid(newDykh);
        QueryWrapper upWrapper = new QueryWrapper<FaGreeSms>()
                .eq("order_base_id", sourceData.getOrderNo())
                .eq("azorwx",2)
                .and(wrapper->wrapper.isNull("fjid")
                        .or().eq("fjid","").or().eq("fjid",0));
        faGreeSmsService.update(up,upWrapper);
    }

    private void uporderRepairOperatingLogpgid(OutJiasmToGreeUploadTaskList sourceData, OrderBase orderBase, String newDykh) {
        OrderRepairOperatingLog up = new OrderRepairOperatingLog();
        up.setPgid(Long.valueOf(newDykh));
        QueryWrapper upWrapper = new QueryWrapper<OrderRepairOperatingLog>()
                .eq("order_base_id", sourceData.getOrderNo())
                .and(wrapper->wrapper.isNull("pgid")
                        .or().eq("pgid",0));
        orderRepairOperatingLogService.update(up,upWrapper);
    }

    private void upOrderBasePgguid(OutJiasmToGreeUploadTaskList sourceData, OrderBase orderBase) {
        if (StringUtils.isEmpty(orderBase.getPgguid()) || orderBase.getPgguid().equals("0")){
            OrderBase up = new OrderBase();
            up.setPgguid(UUID.randomUUID().toString());
            QueryWrapper upWrapper = new QueryWrapper<OrderBase>()
                    .eq("id", sourceData.getOrderNo())
                    .and(wrapper->wrapper.isNull("pgguid")
                            .or().eq("pgguid","").or().eq("pgguid",0));
            orderBaseService.update(up,upWrapper);
        }
    }

    private void upOrderBasePgid(OutJiasmToGreeUploadTaskList sourceData, OrderBase orderBase, String newDykh) {
        if (StringUtils.isEmpty(orderBase.getPgid()) || orderBase.getPgid().equals("0")){
            OrderBase up = new OrderBase();
            up.setPgid(newDykh);
            QueryWrapper upWrapper = new QueryWrapper<OrderBase>()
                    .eq("id", sourceData.getOrderNo())
                    .and(wrapper->wrapper.isNull("pgid")
                            .or().eq("pgid",0));
            orderBaseService.update(up,upWrapper);
        }
    }

    private void stopUpload(@NotNull OutJiasmToGreeUploadTaskList ojtutl, String msg) {
        OutJiasmToGreeUploadTaskList up = new OutJiasmToGreeUploadTaskList();
        up.setSynReqId(ojtutl.getSynReqId());
        up.setSynStatus(99);
        up.setSynTime(new Date());
        up.setSynErrMsg(msg);
        outJiasmToGreeUploadTaskListService.updateById(up);
    }
}
